Package: gMOIP
Type: Package
Title: Tools for 2D and 3D Plots of Single and Multi-Objective
        Linear/Integer Programming Models
Version: 1.5.6
Authors@R: person("Lars", "Relund Nielsen", email = "lars@relund.dk", role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0002-4802-3071"))
URL: https://relund.github.io/gMOIP/, https://github.com/relund/gMOIP/
BugReports: https://github.com/relund/gMOIP/issues
Description: Make 2D and 3D plots of linear programming (LP), 
    integer linear programming (ILP), or mixed integer linear programming (MILP) models 
    with up to three objectives. Plots of both the solution and criterion space are possible.
    For instance the non-dominated (Pareto) set for bi-objective LP/ILP/MILP programming models 
    (see vignettes for an overview). The package also contains an function for checking if a point
    is inside the convex hull.
License: GPL (>= 3)
Language: en-US
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.5.0)
Imports: ggrepel, geometry, ggplot2, rgl, MASS, Matrix, grDevices,
        stats, Rfast, plyr, tidyselect, tidyr, tibble, purrr, dplyr,
        rlang, png, sp, moocore
Suggests: tikzDevice, grid, gridExtra, knitr, rmarkdown, roxygen2,
        ggsci, magrittr, scales, pdftools, testthat (>= 2.1.0),
        webshot2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-03-01 10:03:41 UTC; au15463
Author: Lars Relund Nielsen [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4802-3071>)
Maintainer: Lars Relund Nielsen <lars@relund.dk>
Repository: CRAN
Date/Publication: 2026-03-01 10:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:46:41 UTC; unix
