# Generated by roxygen2: do not edit by hand

export(addNDSet)
export(addNDSet2D)
export(addRays)
export(binaryPoints)
export(classifyNDSet)
export(classifyNDSetExtreme)
export(convexHull)
export(cornerPoints)
export(criterionPoints)
export(dimFace)
export(finalize3D)
export(gMOIPTheme)
export(genNDSet)
export(genSample)
export(getTexture)
export(inHull)
export(ini3D)
export(integerPoints)
export(loadView)
export(plotCones2D)
export(plotCones3D)
export(plotCriterion2D)
export(plotHull2D)
export(plotHull3D)
export(plotMTeX3D)
export(plotNDSet2D)
export(plotPlane3D)
export(plotPoints3D)
export(plotPolygon3D)
export(plotPolytope)
export(plotRectangle3D)
export(plotTeX3D)
export(plotTitleTeX3D)
export(saveView)
export(slices)
export(texToPng)
import(dplyr)
import(ggplot2)
import(rgl)
importFrom(rlang,.data)
importFrom(stats,lm)
importFrom(stats,predict)
