---
title: "Plotting bi-objective models with three variables - Example 1"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Plotting bi-objective models with three variables - Example 1}
  %\VignetteEncoding{UTF-8}
  %\VignetteEngine{knitr::rmarkdown}
editor_options: 
  chunk_output_type: console
---

```{r, include = FALSE}
library(knitr)
library(rgl)
rgl::setupKnitr()
options(rgl.useNULL=TRUE)
opts_chunk$set(
  collapse = TRUE,
  #cache = TRUE, autodep = TRUE, 
  comment = "#>",
  fig.show = "asis", 
  warning=FALSE, message=FALSE, include = TRUE, 
  out.width = "99%", fig.width = 8, fig.align = "center", fig.asp = 0.62
)

if (!requireNamespace("rmarkdown", quietly = TRUE) || !rmarkdown::pandoc_available("1.14")) {
   warning(call. = FALSE, "These vignettes assume rmarkdown and pandoc version 1.14 (or higher). These were not found. Older versions will not work.")
   knitr::knit_exit()
}
```

With `gMOIP` you can make plots of the criterion space for bi-objective models (linear
programming (LP), integer linear programming (ILP), or mixed integer linear programming (MILP)).
This vignette gives examples on how to make plots of both the solution and criterion space.

First we load the package:

```{r setup}
library(gMOIP)
```

We define functions for plotting the solution and criterion space:

```{r 3DPlotFunction}
plotSol <- function(A, b, type = rep("c", ncol(A)),
                        faces = rep("c", ncol(A)),
                        plotFaces = TRUE, labels = "numb")
{
   #loadView(v = view, close = F, zoom = 0.75)
   plotPolytope(A, b, type = type, faces = faces, labels = labels, plotFaces = plotFaces, 
                argsTitle3d = list(main = "Solution space"))
}

plotCrit <- function(A, b, obj, crit = "min", type = rep("c", ncol(A)), addTriangles = TRUE, 
                     labels = "numb") 
{
    plotCriterion2D(A, b, obj, type = type, crit = crit, addTriangles = addTriangles, 
                   labels = labels) + 
      ggplot2::ggtitle("Criterion space")
}
```

We define the model  $\max \{cx | Ax \leq b\}$ (could also be minimized) with three variables:

```{r Ex1Model}
Ab <- matrix( c(
   1, 1, 2, 5,
   2, -1, 0, 3,
   -1, 2, 1, 3,
   0, -3, 5, 2
), nc = 4, byrow = TRUE)
A <- Ab[,1:3]
b <- Ab[,4]
obj <- matrix(c(1, -6, 3, -4, 1, 6), nrow = 2)
```

We load the preferred view angle for the RGL window:

```{r Ex1View}
view <- matrix( c(-0.452365815639496, -0.446501553058624, 0.77201122045517, 0, 0.886364221572876,
                  -0.320795893669128, 0.333835482597351, 0, 0.0986008867621422, 0.835299551486969,
                  0.540881276130676, 0, 0, 0, 0, 1), nc = 4)
loadView(v = view)
```

LP model (solution space):

```{r Ex1LPSol, webgl = TRUE}
plotSol(A, b)
```

LP model (criterion space):

```{r Ex1LPCrit}
plotCrit(A, b, obj, addTriangles = FALSE) 
```

ILP model (solution space):

```{r Ex1ILPSol, webgl = TRUE}
plotSol(A, b, type = c("i","i","i"))
```

ILP model (criterion space):

```{r Ex1ILPCrit}
plotCrit(A, b, obj, type = c("i","i","i"))
```

MILP model with variable 2 and 3 integer (solution space):

```{r Ex1MILPSol1, webgl = TRUE}
plotSol(A, b, type = c("c","i","i"))
```

MILP model with variable 2 and 3 integer (criterion space):

```{r Ex1MILPCrit1}
plotCrit(A, b, obj, type = c("c","i","i"))
```

MILP model with variable 1 and 3 integer (solution space):

```{r Ex1MILPSol2, webgl = TRUE}
plotSol(A, b, type = c("i","c","i"))
```

MILP model with variable 1 and 3 integer (criterion space):

```{r Ex1MILPCrit2}
plotCrit(A, b, obj, type = c("i","c","i"))
```

MILP model with variable 1 and 2 integer (solution space):

```{r Ex1MILPSol3, webgl = TRUE}
plotSol(A, b, type = c("i","i","c"))
```

MILP model with variable 1 and 2 integer (criterion space):

```{r Ex1MILPCrit3}
plotCrit(A, b, obj, type = c("i","i","c"))
```

MILP model with variable 1 integer (solution space):

```{r Ex1NILP4Sol, webgl = TRUE}
plotSol(A, b, type = c("i","c","c"), plotFaces = F)
```

MILP model with variable 1 integer (criterion space):

```{r Ex1MILP4Crit}
plotCrit(A, b, obj, type = c("i","c","c"))
```

MILP model with variable 2 integer (solution space):

```{r Ex1MILPSol5, webgl = TRUE}
plotSol(A, b, type = c("c","i","c"), plotFaces = F)
```

MILP model with variable 2 integer (criterion space):

```{r Ex1MILPCrit5}
plotCrit(A, b, obj, type = c("c","i","c"))
```

MILP model with variable 3 integer (solution space):

```{r Ex1MILPSol6, webgl=TRUE}
plotSol(A, b, type = c("c","c","i"), plotFaces = F)
```

MILP model with variable 3 integer (criterion space):

```{r Ex1MILPCrit6}
plotCrit(A, b, obj, type = c("c","c","i"))
```

```{r, include=F}
rm(list = ls(all.names = TRUE))
```

